﻿using System;
using System.ComponentModel;
using CoreGraphics;
using Foundation;
using Microsoft.Maui.Graphics;
using Microsoft.Maui.Handlers;
using UIKit;

namespace Pink_Template
{
    
    public partial class ModernContentPageRender: PageHandler
    {

        static UISearchController searchController = new UISearchController(searchResultsController: null);


        public static IPropertyMapper<ModernContentPage, ModernContentPageRender> PropertyMapper = new PropertyMapper<ModernContentPage, ModernContentPageRender>(PageHandler.Mapper)
        {
            [nameof(ModernContentPage.SearchTextProperty)] = SearchTextProperty,
            [nameof(ModernContentPage.SearchPlaceholderProperty)] = SearchPlaceholderProperty,



        };

        public ModernContentPageRender() : base(PropertyMapper)
        {

        }

        static void SearchTextProperty(PageHandler handler, ModernContentPage ModernContentPage)
        {
            searchController.SearchBar.Text = ModernContentPage.SearchText;

        }

        static void SearchPlaceholderProperty(PageHandler handler, ModernContentPage ModernContentPage)
        {
            searchController.SearchBar.Placeholder = ModernContentPage.SearchPlaceholder;


            //************************************************************
            //************  Uitlezen acties searchbar   ******************
            //************************************************************

            ModernContentPage.PropertyChanged += (sender, e) =>
            {
                if (e.PropertyName== "SearchText")
                    searchController.SearchBar.Text = ModernContentPage.SearchText;
            };


            searchController.SearchBar.SearchButtonClicked += (sender, e) =>
            {
                if (ModernContentPage.SearchCommand != null && ModernContentPage.SearchCommand.CanExecute(searchController.SearchBar.Text))
                {
                    ModernContentPage.SearchCommand.Execute(searchController.SearchBar.Text);
                }
            };

            searchController.SearchBar.TextChanged += (sender, e) =>
            {
                ModernContentPage.SearchText = searchController.SearchBar.Text;
                if (string.IsNullOrEmpty(searchController.SearchBar.Text))
                {
                    if (ModernContentPage.SearchCancelledCommand != null && ModernContentPage.SearchCancelledCommand.CanExecute(null))
                    {
                        ModernContentPage.SearchCancelledCommand.Execute(null);
                    }
                }
            };

            searchController.SearchBar.CancelButtonClicked += (sender, e) =>
            {
                ModernContentPage.SearchText = searchController.SearchBar.Text= string.Empty;

                if (ModernContentPage.SearchCancelledCommand != null && ModernContentPage.SearchCancelledCommand.CanExecute(null))
                {
                    ModernContentPage.SearchCancelledCommand.Execute(null);
                }

            };

            searchController.SearchBar.OnEditingStarted += (sender, e) =>
            {
                ModernContentPage.IsSearchFocused = true;

            };

            searchController.SearchBar.OnEditingStopped += (sender, e) =>
            {
                ModernContentPage.IsSearchFocused = false;

            };

        }

       

        protected override void ConnectHandler(Microsoft.Maui.Platform.ContentView nativeView)
        {
            base.ConnectHandler(nativeView);
            ContentPage.Loaded += OnLoaded;
        }

        protected override void DisconnectHandler(Microsoft.Maui.Platform.ContentView nativeView)
        {
            ContentPage.Loaded -= OnLoaded;
            base.DisconnectHandler(nativeView);
        }

        ContentPage ContentPage => VirtualView as ContentPage;

        void OnLoaded(object sender, EventArgs e) => ConfigureInteractive();

        void ConfigureInteractive()
        {
            if (this is IPlatformViewHandler handler && handler.ViewController?.ParentViewController is UIKit.UIViewController navControler)
            {
                searchController.HidesNavigationBarDuringPresentation = true;
                searchController.ObscuresBackgroundDuringPresentation = false;
                searchController.DefinesPresentationContext = true;
                     
                searchController.SearchBar.SearchBarStyle = UISearchBarStyle.Default;
                searchController.SearchBar.Translucent = true;

                navControler.NavigationItem.SearchController = ModernContentPageRender.searchController;
                navControler.NavigationItem.HidesSearchBarWhenScrolling = false;
            } 
        }

        
    }

}

